@@ -1,4 +1,4 @@
-/* Copyright (c) 2003, Keith Gudger
+/* Copyright (c) 2003,2005 Keith Gudger
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,6 +28,8 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
+/* $Id: io43u35x.h 2434 2014-08-05 06:57:11Z pitchumani $ */
+
 /* avr/io43u35x.h - definitions for AT43USB35x */
 
 #ifndef _AVR_IO43U35X_H_
@@ -184,6 +186,7 @@
 #define SIG_INTERRUPT0		_VECTOR(1)  /* suspend/resume */
 #define SIG_INTERRUPT1		_VECTOR(2)
 #define SIG_TIMER1_CAPT1	_VECTOR(3)
+#define SIG_INPUT_CAPTURE1	_VECTOR(3)
 #define SIG_OUTPUT_COMPARE1A		_VECTOR(4)
 #define SIG_OUTPUT_COMPARE1B		_VECTOR(5)
 #define SIG_OVERFLOW1		_VECTOR(6)
@@ -417,8 +420,9 @@
 #define    ADPS0    0  
 
 /* Constants */
+#define    RAMSTART 0x60
 #define    RAMEND   0x045F     /*Last On-Chip SRAM Location*/
-#define    XRAMEND  0x045F
+#define    XRAMEND  RAMEND
 #define    E2END    0x0000
 #define    FLASHEND 0x5FFF
 
