@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io90pwm316.h,v 1.7 2007/12/19 00:29:06 arcanum Exp $ */
+/* $Id: io90pwm316.h 2434 2014-08-05 06:57:11Z pitchumani $ */
 
 /* avr/io90pwm316.h - definitions for AT90PWM316 */
 
@@ -908,8 +908,8 @@
 #define PSOC1   _SFR_MEM8(0xE0)
 #define POEN1A 0
 #define POEN1B 2
-#define PSYNC1 4
-#define PSYNC1 5
+#define PSYNC1_0 4
+#define PSYNC1_1 5
 
 /* Output Compare SA Registers */
 #define OCR1SA  _SFR_MEM16(0xE2)
@@ -1076,96 +1076,127 @@
 /* Interrupt 0 is the reset vector. */
 
 /* PSC2 Capture Event */
+#define PSC2_CAPT_vect_num 1
 #define PSC2_CAPT_vect     _VECTOR(1)
 
 /* PSC2 End Cycle */
+#define PSC2_EC_vect_num   2
 #define PSC2_EC_vect       _VECTOR(2)
 
 /* PSC1 Capture Event */
+#define PSC1_CAPT_vect_num 3
 #define PSC1_CAPT_vect     _VECTOR(3)
 
 /* PSC1 End Cycle */
+#define PSC1_EC_vect_num   4
 #define PSC1_EC_vect       _VECTOR(4)
 
 /* PSC0 Capture Event */
+#define PSC0_CAPT_vect_num 5
 #define PSC0_CAPT_vect     _VECTOR(5)
 
 /* PSC0 End Cycle */
+#define PSC0_EC_vect_num   6
 #define PSC0_EC_vect       _VECTOR(6)
 
 /* Analog Comparator 0 */
+#define ANALOG_COMP_0_vect_num 7
 #define ANALOG_COMP_0_vect _VECTOR(7)
 
 /* Analog Comparator 1 */
+#define ANALOG_COMP_1_vect_num 8
 #define ANALOG_COMP_1_vect _VECTOR(8)
 
 /* Analog Comparator 2 */
+#define ANALOG_COMP_2_vect_num 9
 #define ANALOG_COMP_2_vect _VECTOR(9)
 
 /* External Interrupt Request 0 */
+#define INT0_vect_num      10
 #define INT0_vect          _VECTOR(10)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num 11
 #define TIMER1_CAPT_vect   _VECTOR(11)
 
 /* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect_num  12
 #define TIMER1_COMPA_vect  _VECTOR(12)
 
 /* Timer/Counter Compare Match B */
+#define TIMER1_COMPB_vect_num  13
 #define TIMER1_COMPB_vect  _VECTOR(13)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num 15
 #define TIMER1_OVF_vect    _VECTOR(15)
 
 /* Timer/Counter0 Compare Match A */
+#define TIMER0_COMP_A_vect_num 16
 #define TIMER0_COMP_A_vect _VECTOR(16)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num 17
 #define TIMER0_OVF_vect    _VECTOR(17)
 
 /* ADC Conversion Complete */
+#define ADC_vect_num       18
 #define ADC_vect           _VECTOR(18)
 
 /* External Interrupt Request 1 */
+#define INT1_vect_num      19
 #define INT1_vect          _VECTOR(19)
 
 /* SPI Serial Transfer Complete */
+#define SPI_STC_vect_num   20
 #define SPI_STC_vect       _VECTOR(20)
 
 /* USART, Rx Complete */
+#define USART_RX_vect_num  21
 #define USART_RX_vect      _VECTOR(21)
 
 /* USART Data Register Empty */
+#define USART_UDRE_vect_num 22
 #define USART_UDRE_vect    _VECTOR(22)
 
 /* USART, Tx Complete */
+#define USART_TX_vect_num  23
 #define USART_TX_vect      _VECTOR(23)
 
 /* External Interrupt Request 2 */
+#define INT2_vect_num      24
 #define INT2_vect          _VECTOR(24)
 
 /* Watchdog Timeout Interrupt */
+#define WDT_vect_num       25
 #define WDT_vect           _VECTOR(25)
 
 /* EEPROM Ready */
+#define EE_READY_vect_num  26
 #define EE_READY_vect      _VECTOR(26)
 
 /* Timer Counter 0 Compare Match B */
+#define TIMER0_COMPB_vect_num 27
 #define TIMER0_COMPB_vect  _VECTOR(27)
 
 /* External Interrupt Request 3 */
+#define INT3_vect_num      28
 #define INT3_vect          _VECTOR(28)
 
 /* Store Program Memory Read */
+#define SPM_READY_vect_num 31
 #define SPM_READY_vect     _VECTOR(31)
 
 #define _VECTORS_SIZE   (4 * 32)
 
 /* Constants */
 
+#define RAMSTART       0x100
 #define RAMEND         0x4FF
-#define XRAMEND        0
+#define XRAMSIZE       0
+#define XRAMEND        RAMEND
 #define E2END          0x1FF
+#define E2PAGESIZE     4
 #define FLASHEND       0x3FFF
 #define SPM_PAGESIZE   128
 
@@ -1175,36 +1206,36 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define CKSEL0  ~_BV(0)  /* Select Clock Source */
-#define CKSEL1  ~_BV(1)  /* Select Clock Source */
-#define CKSEL2  ~_BV(2)  /* Select Clock Source */
-#define CKSEL3  ~_BV(3)  /* Select Clock Source */
-#define SUT0    ~_BV(4)  /* Select start-up time */
-#define SUT1    ~_BV(5)  /* Select start-up time */
-#define CKOUT   ~_BV(6)  /* Oscillator output option */
-#define CKDIV8  ~_BV(7)  /* Divide clock by 8 */
-#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
+#define FUSE_CKSEL0  (unsigned char)~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1  (unsigned char)~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2  (unsigned char)~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3  (unsigned char)~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0    (unsigned char)~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1    (unsigned char)~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT   (unsigned char)~_BV(6)  /* Oscillator output option */
+#define FUSE_CKDIV8  (unsigned char)~_BV(7)  /* Divide clock by 8 */
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define BODLEVEL0 ~_BV(0)
-#define BODLEVEL1 ~_BV(1)
-#define BODLEVEL2 ~_BV(2)
-#define EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define WDTON     ~_BV(4)  /* Watchdog timer always on */
-#define SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define DWEN      ~_BV(6)  /* debugWIRE Enable */
-#define RSTDISBL  ~_BV(7)  /* External Reset Diasble */
-#define HFUSE_DEFAULT (SPIEN)
+#define FUSE_BODLEVEL0 (unsigned char)~_BV(0)
+#define FUSE_BODLEVEL1 (unsigned char)~_BV(1)
+#define FUSE_BODLEVEL2 (unsigned char)~_BV(2)
+#define FUSE_EESAVE    (unsigned char)~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON     (unsigned char)~_BV(4)  /* Watchdog timer always on */
+#define FUSE_SPIEN     (unsigned char)~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN      (unsigned char)~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL  (unsigned char)~_BV(7)  /* External Reset Diasble */
+#define HFUSE_DEFAULT (FUSE_SPIEN)
 
 /* Extended Fuse Byte */
-#define BOOTRST  ~_BV(0)  /* Select Reset Vector */
-#define BOOTSZ0  ~_BV(1)  /* Select Boot Size */
-#define BOOTSZ1  ~_BV(2)  /* Select Boot Size */
-#define PSCRV    ~_BV(4)
-#define PSC0RB   ~_BV(5)
-#define PSC1RB   ~_BV(6)
-#define PSC2RB   ~_BV(7)
-#define EFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1)
+#define FUSE_BOOTRST  (unsigned char)~_BV(0)  /* Select Reset Vector */
+#define FUSE_BOOTSZ0  (unsigned char)~_BV(1)  /* Select Boot Size */
+#define FUSE_BOOTSZ1  (unsigned char)~_BV(2)  /* Select Boot Size */
+#define FUSE_PSCRV    (unsigned char)~_BV(4)
+#define FUSE_PSC0RB   (unsigned char)~_BV(5)
+#define FUSE_PSC1RB   (unsigned char)~_BV(6)
+#define FUSE_PSC2RB   (unsigned char)~_BV(7)
+#define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
 
 
 /* Lock Bits */
@@ -1213,4 +1244,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x94
+#define SIGNATURE_2 0x83
+
+
 #endif /* _AVR_IO90PWM316_H_ */
