@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom163.h,v 1.14 2007/12/12 04:36:54 arcanum Exp $ */
+/* $Id: iom163.h 2434 2014-08-05 06:57:11Z pitchumani $ */
 
 /* avr/iom163.h - definitions for ATmega163 */
 
@@ -166,71 +166,88 @@
 /* Interrupt vectors */
 
 /* External Interrupt 0 */
-#define INT0_vect			_VECTOR(1)
-#define SIG_INTERRUPT0			_VECTOR(1)
+#define INT0_vect_num		    1
+#define INT0_vect			    _VECTOR(1)
+#define SIG_INTERRUPT0		    _VECTOR(1)
 
 /* External Interrupt 1 */
-#define INT1_vect			_VECTOR(2)
-#define SIG_INTERRUPT1			_VECTOR(2)
+#define INT1_vect_num		    2
+#define INT1_vect			    _VECTOR(2)
+#define SIG_INTERRUPT1		    _VECTOR(2)
 
 /* Timer/Counter2 Compare Match */
+#define TIMER2_COMP_vect_num	3
 #define TIMER2_COMP_vect		_VECTOR(3)
 #define SIG_OUTPUT_COMPARE2		_VECTOR(3)
 
 /* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect_num		4
 #define TIMER2_OVF_vect			_VECTOR(4)
 #define SIG_OVERFLOW2			_VECTOR(4)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num	5
 #define TIMER1_CAPT_vect		_VECTOR(5)
 #define SIG_INPUT_CAPTURE1		_VECTOR(5)
 
 /* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect_num	6
 #define TIMER1_COMPA_vect		_VECTOR(6)
-#define SIG_OUTPUT_COMPARE1A		_VECTOR(6)
+#define SIG_OUTPUT_COMPARE1A	_VECTOR(6)
 
 /* Timer/Counter1 Compare Match B */
+#define TIMER1_COMPB_vect_num	7
 #define TIMER1_COMPB_vect		_VECTOR(7)
-#define SIG_OUTPUT_COMPARE1B		_VECTOR(7)
+#define SIG_OUTPUT_COMPARE1B	_VECTOR(7)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num		8
 #define TIMER1_OVF_vect			_VECTOR(8)
 #define SIG_OVERFLOW1			_VECTOR(8)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		9
 #define TIMER0_OVF_vect			_VECTOR(9)
 #define SIG_OVERFLOW0			_VECTOR(9)
 
 /* SPI Serial Transfer Complete */
+#define SPI_STC_vect_num		10
 #define SPI_STC_vect			_VECTOR(10)
-#define SIG_SPI				_VECTOR(10)
+#define SIG_SPI				    _VECTOR(10)
 
 /* UART, RX Complete */
+#define UART_RX_vect_num		11
 #define UART_RX_vect			_VECTOR(11)
 #define SIG_UART_RECV			_VECTOR(11)
 
 /* UART Data Register Empty */
+#define UART_UDRE_vect_num		12
 #define UART_UDRE_vect			_VECTOR(12)
 #define SIG_UART_DATA			_VECTOR(12)
 
 /* UART, TX Complete */
+#define UART_TX_vect_num		13
 #define UART_TX_vect			_VECTOR(13)
 #define SIG_UART_TRANS			_VECTOR(13)
 
 /* ADC Conversion Complete */
-#define ADC_vect			_VECTOR(14)
-#define SIG_ADC				_VECTOR(14)
+#define ADC_vect_num			14
+#define ADC_vect		    	_VECTOR(14)
+#define SIG_ADC				    _VECTOR(14)
 
 /* EEPROM Ready */
-#define EE_RDY_vect			_VECTOR(15)
+#define EE_RDY_vect_num			15
+#define EE_RDY_vect			    _VECTOR(15)
 #define SIG_EEPROM_READY		_VECTOR(15)
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		16
 #define ANA_COMP_vect			_VECTOR(16)
 #define SIG_COMPARATOR			_VECTOR(16)
 
 /* 2-Wire Serial Interface */
-#define TWI_vect			_VECTOR(17)
+#define TWI_vect_num			17
+#define TWI_vect			    _VECTOR(17)
 #define SIG_2WIRE_SERIAL		_VECTOR(17)
 
 #define _VECTORS_SIZE 72
@@ -596,9 +613,11 @@
 
 /* Constants */
 #define SPM_PAGESIZE 128
+#define RAMSTART    0x60
 #define RAMEND		0x45F
-#define XRAMEND		0x45F
+#define XRAMEND		RAMEND
 #define E2END		0x1FF
+#define E2PAGESIZE  0
 #define FLASHEND	0x3FFF
 
 
@@ -607,19 +626,19 @@
 #define FUSE_MEMORY_SIZE 2
 
 /* Low Fuse Byte */
-#define CKSEL0      ~_BV(0)
-#define CKSEL1      ~_BV(1)
-#define CKSEL2      ~_BV(2)
-#define CKSEL3      ~_BV(3)
-#define SPIEN       ~_BV(5)
-#define BODEN       ~_BV(6)
-#define BODLEVEL    ~_BV(7)
-#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SPIEN)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_BODEN       (unsigned char)~_BV(6)
+#define FUSE_BODLEVEL    (unsigned char)~_BV(7)
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SPIEN)
 
 /* High Fuse Byte */
-#define BOOTRST     ~_BV(0)
-#define BOOTSZ0     ~_BV(1)
-#define BOOTSZ1     ~_BV(2)
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
 #define HFUSE_DEFAULT (0xFF)
 
 
@@ -629,4 +648,38 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x94
+#define SIGNATURE_2 0x02
+
+
+/* Deprecated items */
+#if !defined(__AVR_LIBC_DEPRECATED_ENABLE__)
+
+#pragma GCC system_header
+
+#pragma GCC poison SIG_INTERRUPT0
+#pragma GCC poison SIG_INTERRUPT1
+#pragma GCC poison SIG_OUTPUT_COMPARE2
+#pragma GCC poison SIG_OVERFLOW2
+#pragma GCC poison SIG_INPUT_CAPTURE1
+#pragma GCC poison SIG_OUTPUT_COMPARE1A
+#pragma GCC poison SIG_OUTPUT_COMPARE1B
+#pragma GCC poison SIG_OVERFLOW1
+#pragma GCC poison SIG_OVERFLOW0
+#pragma GCC poison SIG_SPI
+#pragma GCC poison SIG_UART_RECV
+#pragma GCC poison SIG_UART_DATA
+#pragma GCC poison SIG_UART_TRANS
+#pragma GCC poison SIG_ADC
+#pragma GCC poison SIG_EEPROM_READY
+#pragma GCC poison SIG_COMPARATOR
+#pragma GCC poison SIG_2WIRE_SERIAL
+
+#endif  /* !defined(__AVR_LIBC_DEPRECATED_ENABLE__) */
+
+
+
+
 #endif /* _AVR_IOM163_H_ */
