@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom323.h,v 1.13.2.6 2009/02/11 18:05:27 arcanum Exp $ */
+/* $Id: iom323.h 2434 2014-08-05 06:57:11Z pitchumani $ */
 
 /* avr/iom323.h - definitions for ATmega323 */
 
@@ -171,82 +171,102 @@
 /* Interrupt vectors */
 
 /* External Interrupt Request 0 */
+#define INT0_vect_num		1
 #define INT0_vect			_VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* External Interrupt Request 1 */
+#define INT1_vect_num		2
 #define INT1_vect			_VECTOR(2)
 #define SIG_INTERRUPT1			_VECTOR(2)
 
 /* External Interrupt Request 2 */
+#define INT2_vect_num		3
 #define INT2_vect			_VECTOR(3)
 #define SIG_INTERRUPT2			_VECTOR(3)
 
 /* Timer/Counter2 Compare Match */
+#define TIMER2_COMP_vect_num	4
 #define TIMER2_COMP_vect		_VECTOR(4)
 #define SIG_OUTPUT_COMPARE2		_VECTOR(4)
 
 /* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect_num		5
 #define TIMER2_OVF_vect			_VECTOR(5)
 #define SIG_OVERFLOW2			_VECTOR(5)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num	6
 #define TIMER1_CAPT_vect		_VECTOR(6)
 #define SIG_INPUT_CAPTURE1		_VECTOR(6)
 
 /* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect_num	7
 #define TIMER1_COMPA_vect		_VECTOR(7)
 #define SIG_OUTPUT_COMPARE1A		_VECTOR(7)
 
 /* Timer/Counter1 Compare Match B */
+#define TIMER1_COMPB_vect_num	8
 #define TIMER1_COMPB_vect		_VECTOR(8)
 #define SIG_OUTPUT_COMPARE1B		_VECTOR(8)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num		9
 #define TIMER1_OVF_vect			_VECTOR(9)
 #define SIG_OVERFLOW1			_VECTOR(9)
 
 /* Timer/Counter0 Compare Match */
+#define TIMER0_COMP_vect_num	10
 #define TIMER0_COMP_vect		_VECTOR(10)
 #define SIG_OUTPUT_COMPARE0		_VECTOR(10)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		11
 #define TIMER0_OVF_vect			_VECTOR(11)
 #define SIG_OVERFLOW0			_VECTOR(11)
 
 /* Serial Transfer Complete */
+#define SPI_STC_vect_num		12
 #define SPI_STC_vect			_VECTOR(12)
 #define SIG_SPI				_VECTOR(12)
 
 /* USART, Rx Complete */
+#define USART_RXC_vect_num		13
 #define USART_RXC_vect			_VECTOR(13)
 #define SIG_UART_RECV			_VECTOR(13)
 
 /* USART Data Register Empty */
+#define USART_UDRE_vect_num		14
 #define USART_UDRE_vect			_VECTOR(14)
 #define SIG_UART_DATA			_VECTOR(14)
 
 /* USART, Tx Complete */
+#define USART_TXC_vect_num		15
 #define USART_TXC_vect			_VECTOR(15)
 #define SIG_UART_TRANS			_VECTOR(15)
 
 /* ADC Conversion Complete */
+#define ADC_vect_num		16
 #define ADC_vect			_VECTOR(16)
 #define SIG_ADC				_VECTOR(16)
 
 /* EEPROM Ready */
+#define EE_RDY_vect_num		17
 #define EE_RDY_vect			_VECTOR(17)
 #define SIG_EEPROM_READY		_VECTOR(17)
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		18
 #define ANA_COMP_vect			_VECTOR(18)
 #define SIG_COMPARATOR			_VECTOR(18)
 
 /* 2-wire Serial Interface */
+#define TWI_vect_num		19
 #define TWI_vect			_VECTOR(19)
 #define SIG_2WIRE_SERIAL		_VECTOR(19)
 
 /* Store Program Memory Ready */
+#define SPM_RDY_vect_num		20
 #define SPM_RDY_vect			_VECTOR(20)
 
 #define _VECTORS_SIZE 80
@@ -642,6 +662,7 @@
 
 /* Constants */
 #define SPM_PAGESIZE 128
+#define RAMSTART    0x60
 #define RAMEND		0x85F
 #define XRAMEND		RAMEND
 #define E2END		0x3FF
@@ -685,4 +706,33 @@
 #define SIGNATURE_2 0x01
 
 
+/* Deprecated items */
+#if !defined(__AVR_LIBC_DEPRECATED_ENABLE__)
+
+#pragma GCC system_header
+
+#pragma GCC poison SIG_INTERRUPT0
+#pragma GCC poison SIG_INTERRUPT1
+#pragma GCC poison SIG_INTERRUPT2
+#pragma GCC poison SIG_OUTPUT_COMPARE2
+#pragma GCC poison SIG_OVERFLOW2
+#pragma GCC poison SIG_INPUT_CAPTURE1
+#pragma GCC poison SIG_OUTPUT_COMPARE1A
+#pragma GCC poison SIG_OUTPUT_COMPARE1B
+#pragma GCC poison SIG_OVERFLOW1
+#pragma GCC poison SIG_OUTPUT_COMPARE0
+#pragma GCC poison SIG_OVERFLOW0
+#pragma GCC poison SIG_SPI
+#pragma GCC poison SIG_UART_RECV
+#pragma GCC poison SIG_UART_DATA
+#pragma GCC poison SIG_UART_TRANS
+#pragma GCC poison SIG_ADC
+#pragma GCC poison SIG_EEPROM_READY
+#pragma GCC poison SIG_COMPARATOR
+#pragma GCC poison SIG_2WIRE_SERIAL
+
+#endif  /* !defined(__AVR_LIBC_DEPRECATED_ENABLE__) */
+
+
+
 #endif /* _AVR_IOM323_H_ */
