@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: iom88p.h,v 1.3.2.6 2008/03/19 21:25:13 arcanum Exp $ */
+/* $Id: iom88p.h 2445 2014-08-11 22:21:45Z joerg_wunsch $ */
 
 /* avr/iom88p.h - definitions for ATmega88P. */
 
@@ -244,14 +244,14 @@
 #define TCNT0_7 7
 
 #define OCR0A _SFR_IO8(0x27)
-#define OCROA_0 0
-#define OCROA_1 1
-#define OCROA_2 2
-#define OCROA_3 3
-#define OCROA_4 4
-#define OCROA_5 5
-#define OCROA_6 6
-#define OCROA_7 7
+#define OCR0A_0 0
+#define OCR0A_1 1
+#define OCR0A_2 2
+#define OCR0A_3 3
+#define OCR0A_4 4
+#define OCR0A_5 5
+#define OCR0A_6 6
+#define OCR0A_7 7
 
 #define OCR0B _SFR_IO8(0x28)
 #define OCR0B_0 0
@@ -339,10 +339,12 @@
 
 #define SPMCSR _SFR_IO8(0x37)
 #define SELFPRGEN 0
+#define SPMEN 0
 #define PGERS 1
 #define PGWRT 2
 #define BLBSET 3
 #define RWWSRE 4
+#define SIGRD 5
 #define RWWSB 6
 #define SPMIE 7
 
@@ -438,7 +440,10 @@
 #define OCIE2A 1
 #define OCIE2B 2
 
-#define ADC _SFR_MEM16(0x78)
+#ifndef __ASSEMBLER__
+#define ADC     _SFR_MEM16(0x78)
+#endif
+#define ADCW    _SFR_MEM16(0x78)
 
 #define ADCL _SFR_MEM8(0x78)
 #define ADCL0 0
@@ -782,30 +787,79 @@
 
 /* Interrupt Vectors */
 /* Interrupt Vector 0 is the reset vector. */
+#define INT0_vect_num     1
 #define INT0_vect         _VECTOR(1)   /* External Interrupt Request 0 */
+
+#define INT1_vect_num     2
 #define INT1_vect         _VECTOR(2)   /* External Interrupt Request 1 */
+
+#define PCINT0_vect_num   3
 #define PCINT0_vect       _VECTOR(3)   /* Pin Change Interrupt Request 0 */
+
+#define PCINT1_vect_num   4
 #define PCINT1_vect       _VECTOR(4)   /* Pin Change Interrupt Request 0 */
+
+#define PCINT2_vect_num   5
 #define PCINT2_vect       _VECTOR(5)   /* Pin Change Interrupt Request 1 */
+
+#define WDT_vect_num      6
 #define WDT_vect          _VECTOR(6)   /* Watchdog Time-out Interrupt */
+
+#define TIMER2_COMPA_vect_num 7
 #define TIMER2_COMPA_vect _VECTOR(7)   /* Timer/Counter2 Compare Match A */
+
+#define TIMER2_COMPB_vect_num 8
 #define TIMER2_COMPB_vect _VECTOR(8)   /* Timer/Counter2 Compare Match A */
+
+#define TIMER2_OVF_vect_num   9
 #define TIMER2_OVF_vect   _VECTOR(9)   /* Timer/Counter2 Overflow */
+
+#define TIMER1_CAPT_vect_num  10
 #define TIMER1_CAPT_vect  _VECTOR(10)  /* Timer/Counter1 Capture Event */
+
+#define TIMER1_COMPA_vect_num 11
 #define TIMER1_COMPA_vect _VECTOR(11)  /* Timer/Counter1 Compare Match A */
+
+#define TIMER1_COMPB_vect_num 12
 #define TIMER1_COMPB_vect _VECTOR(12)  /* Timer/Counter1 Compare Match B */ 
+
+#define TIMER1_OVF_vect_num   13
 #define TIMER1_OVF_vect   _VECTOR(13)  /* Timer/Counter1 Overflow */
+
+#define TIMER0_COMPA_vect_num 14
 #define TIMER0_COMPA_vect _VECTOR(14)  /* TimerCounter0 Compare Match A */
+
+#define TIMER0_COMPB_vect_num 15
 #define TIMER0_COMPB_vect _VECTOR(15)  /* TimerCounter0 Compare Match B */
+
+#define TIMER0_OVF_vect_num   16
 #define TIMER0_OVF_vect   _VECTOR(16)  /* Timer/Couner0 Overflow */
+
+#define SPI_STC_vect_num  17
 #define SPI_STC_vect      _VECTOR(17)  /* SPI Serial Transfer Complete */
+
+#define USART_RX_vect_num 18
 #define USART_RX_vect     _VECTOR(18)  /* USART Rx Complete */
+
+#define USART_UDRE_vect_num   19
 #define USART_UDRE_vect   _VECTOR(19)  /* USART, Data Register Empty */
+
+#define USART_TX_vect_num 20
 #define USART_TX_vect     _VECTOR(20)  /* USART Tx Complete */
+
+#define ADC_vect_num      21
 #define ADC_vect          _VECTOR(21)  /* ADC Conversion Complete */
+
+#define EE_READY_vect_num 22
 #define EE_READY_vect     _VECTOR(22)  /* EEPROM Ready */
+
+#define ANALOG_COMP_vect_num  23
 #define ANALOG_COMP_vect  _VECTOR(23)  /* Analog Comparator */
+
+#define TWI_vect_num      24
 #define TWI_vect          _VECTOR(24)  /* Two-wire Serial Interface */
+
+#define SPM_READY_vect_num    25
 #define SPM_READY_vect    _VECTOR(25)  /* Store Program Memory Read */
 
 #define _VECTORS_SIZE (26 * 2)
@@ -813,11 +867,13 @@
 
 
 /* Constants */
-#define SPM_PAGESIZE 32
+#define SPM_PAGESIZE 64
+#define RAMSTART     (0x100)
 #define RAMEND       0x4FF     /* Last On-Chip SRAM Location */
 #define XRAMSIZE     0
-#define XRAMEND      (RAMEND + XRAMSIZE)
+#define XRAMEND      RAMEND
 #define E2END        0x1FF
+#define E2PAGESIZE   4
 #define FLASHEND     0x1FFF
 
 
@@ -826,31 +882,31 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0 ~_BV(0)  /* Select Clock Source */
-#define FUSE_CKSEL1 ~_BV(1)  /* Select Clock Source */
-#define FUSE_CKSEL2 ~_BV(2)  /* Select Clock Source */
-#define FUSE_CKSEL3 ~_BV(3)  /* Select Clock Source */
-#define FUSE_SUT0   ~_BV(4)  /* Select start-up time */
-#define FUSE_SUT1   ~_BV(5)  /* Select start-up time */
-#define FUSE_CKOUT  ~_BV(6)  /* Clock output */
-#define FUSE_CKDIV8 ~_BV(7) /* Divide clock by 8 */
+#define FUSE_CKSEL0 (unsigned char)~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1 (unsigned char)~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2 (unsigned char)~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3 (unsigned char)~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0   (unsigned char)~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1   (unsigned char)~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT  (unsigned char)~_BV(6)  /* Clock output */
+#define FUSE_CKDIV8 (unsigned char)~_BV(7) /* Divide clock by 8 */
 #define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define FUSE_BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
-#define FUSE_BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
-#define FUSE_BODLEVEL2 ~_BV(2)  /* Brown-out Detector trigger level */
-#define FUSE_EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define FUSE_WDTON     ~_BV(4)  /* Watchdog Timer Always On */
-#define FUSE_SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define FUSE_DWEN      ~_BV(6)  /* debugWIRE Enable */
-#define FUSE_RSTDISBL  ~_BV(7)  /* External reset disable */
+#define FUSE_BODLEVEL0 (unsigned char)~_BV(0)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL1 (unsigned char)~_BV(1)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL2 (unsigned char)~_BV(2)  /* Brown-out Detector trigger level */
+#define FUSE_EESAVE    (unsigned char)~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON     (unsigned char)~_BV(4)  /* Watchdog Timer Always On */
+#define FUSE_SPIEN     (unsigned char)~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN      (unsigned char)~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL  (unsigned char)~_BV(7)  /* External reset disable */
 #define HFUSE_DEFAULT (FUSE_SPIEN)
 
 /* Extended Fuse Byte */
-#define FUSE_BOOTRST ~_BV(0)
-#define FUSE_BOOTSZ0 ~_BV(1)
-#define FUSE_BOOTSZ1 ~_BV(2)
+#define FUSE_BOOTRST (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0 (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1 (unsigned char)~_BV(2)
 #define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
 
 
@@ -861,4 +917,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x93
+#define SIGNATURE_2 0x0F
+
+
 #endif  /* _AVR_IOM88P_H_ */
