@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn12.h,v 1.10 2007/12/12 04:36:56 arcanum Exp $ */
+/* $Id: iotn12.h 2434 2014-08-05 06:57:11Z pitchumani $ */
 
 /* avr/iotn12.h - definitions for ATtiny12 */
 
@@ -124,23 +124,28 @@
 /* Interrupt vectors */
 
 /* External Interrupt 0 */
-#define INT0_vect			_VECTOR(1)
+#define INT0_vect_num			1
+#define INT0_vect	    		_VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* External Interrupt Request 0 */
+#define IO_PINS_vect_num		2
 #define IO_PINS_vect			_VECTOR(2)
-#define SIG_PIN				_VECTOR(2)
+#define SIG_PIN			    	_VECTOR(2)
 #define SIG_PIN_CHANGE			_VECTOR(2)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		3
 #define TIMER0_OVF_vect			_VECTOR(3)
 #define SIG_OVERFLOW0			_VECTOR(3)
 
 /* EEPROM Ready */
-#define EE_RDY_vect			_VECTOR(4)
+#define EE_RDY_vect_num			4
+#define EE_RDY_vect		    	_VECTOR(4)
 #define SIG_EEPROM_READY		_VECTOR(4)
 
 /* Analog Comparator */
+#define ANA_COMP_vect_num		5
 #define ANA_COMP_vect			_VECTOR(5)
 #define SIG_COMPARATOR			_VECTOR(5)
 
@@ -228,10 +233,12 @@
 #define EEWE    1
 #define EERE    0
 
+#define RAMSTART    0x60
 /* Last memory addresses */
 #define RAMEND		0x1F
 #define XRAMEND		0x0
 #define E2END		0x3F
+#define E2PAGESIZE  2
 #define FLASHEND	0x3FF
 
 
@@ -240,19 +247,40 @@
 #define FUSE_MEMORY_SIZE 1
 
 /* Low Fuse Byte */
-#define CKSEL0      ~_BV(0)
-#define CKSEL1      ~_BV(1)
-#define CKSEL2      ~_BV(2)
-#define CKSEL3      ~_BV(3)
-#define RSTDISBL    ~_BV(4)
-#define SPIEN       ~_BV(5)
-#define BODEN       ~_BV(6)
-#define BODLEVEL    ~_BV(7)
-#define FUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SPIEN & BODLEVEL)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_RSTDISBL    (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_BODEN       (unsigned char)~_BV(6)
+#define FUSE_BODLEVEL    (unsigned char)~_BV(7)
+#define FUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SPIEN & FUSE_BODLEVEL)
 
 
 /* Lock Bits */
 #define __LOCK_BITS_EXIST
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x90
+#define SIGNATURE_2 0x05
+
+
+/* Deprecated items */
+#if !defined(__AVR_LIBC_DEPRECATED_ENABLE__)
+
+#pragma GCC system_header
+
+#pragma GCC poison SIG_INTERRUPT0
+#pragma GCC poison SIG_PIN
+#pragma GCC poison SIG_PIN_CHANGE
+#pragma GCC poison SIG_OVERFLOW0
+#pragma GCC poison SIG_EEPROM_READY
+#pragma GCC poison SIG_COMPARATOR
+
+#endif  /* !defined(__AVR_LIBC_DEPRECATED_ENABLE__) */
+
+
 #endif /* _AVR_IOTN12_H_ */
