@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn13a.h,v 1.1.2.7 2009/02/11 18:05:31 arcanum Exp $ */
+/* $Id: iotn13a.h 2415 2014-03-21 16:15:53Z pitchumani $ */
 
 /* avr/iotn13a.h - definitions for ATtiny13 */
 
@@ -149,8 +149,8 @@
 
 #define EECR _SFR_IO8(0x1C)
 #define EERE 0
-#define EEWE 1
-#define EEMWE 2
+#define EEPE 1
+#define EEMPE 2
 #define EERIE 3
 #define EEPM0 4
 #define EEPM1 5
@@ -187,8 +187,7 @@
 
 #define PRR _SFR_IO8(0x25)
 #define PRADC 0
-#define PRSPI 1
-#define PRTIM0 2
+#define PRTIM0 1
 
 #define CLKPR _SFR_IO8(0x26)
 #define CLKPS0 0
@@ -230,8 +229,8 @@
 #define COM0A1 7
 
 #define BODCR _SFR_IO8(0x30)
-#define BPDSE 0
-#define BPDS 1
+#define BODSE 0
+#define BODS 1
 
 #define OSCCAL _SFR_IO8(0x31)
 #define CAL0 0
